@@ -24,4 +24,10 @@ def warnings_recent_content():
     entries = LogEntry.objects.all().order_by('-id')[:10]
     return {
         'log_entries': entries
+    }
+
+@register.inclusion_tag('elements/form.html')
+def simple_form(form):
+    return {
+        'form': form
     }
\ No newline at end of file
